Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(568)

Unified Diff: chrome/test/ui/ppapi_uitest.h

Issue 10409032: Enable PPAPINaCl GLIBC browser_tests. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: More ARM build fixes Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | chrome/test/ui/ppapi_uitest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/ui/ppapi_uitest.h
diff --git a/chrome/test/ui/ppapi_uitest.h b/chrome/test/ui/ppapi_uitest.h
index da9e3d5cb1ae2aa00dc59209b85b3f367a52da51..ec58abae4bb6059343eb9c5cac7b8b9f0c7171f7 100644
--- a/chrome/test/ui/ppapi_uitest.h
+++ b/chrome/test/ui/ppapi_uitest.h
@@ -68,21 +68,28 @@ class OutOfProcessPPAPITest : public PPAPITest {
virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;
};
// NaCl plugin test runner.
class PPAPINaClTest : public PPAPITestBase {
public:
- PPAPINaClTest();
-
virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;
+};
+// NaCl plugin test runner for Newlib runtime.
+class PPAPINaClNewlibTest : public PPAPINaClTest {
+ public:
virtual std::string BuildQuery(const std::string& base,
const std::string& test_case) OVERRIDE;
};
-class PPAPINaClTestDisallowedSockets : public PPAPITestBase {
+// NaCl plugin test runner for GNU-libc runtime.
+class PPAPINaClGLibcTest : public PPAPINaClTest {
public:
- PPAPINaClTestDisallowedSockets();
+ virtual std::string BuildQuery(const std::string& base,
+ const std::string& test_case) OVERRIDE;
+};
+class PPAPINaClTestDisallowedSockets : public PPAPITestBase {
+ public:
virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;
virtual std::string BuildQuery(const std::string& base,
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | chrome/test/ui/ppapi_uitest.cc » ('j') | no next file with comments »
@@ -68,21 +68,28 @@ class OutOfProcessPPAPITest : public PPAPITest {
virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;
};
-// NaCl plugin test runner.
+// NaCl plugin test runner for Newlib runtime.
class PPAPINaClTest : public PPAPITestBase {
public:

Powered by Google App Engine
This is Rietveld 408576698